@@ -4,7 +4,7 @@ import ctypes, logging, os.path, getopt, sys, subprocess
 from fcntl import ioctl
 
 ghurl = 'https://github.com/soyersoyer/cameractrls'
-version = 'v0.4.14'
+version = 'v0.5.0'
 
 
 v4ldirs = {
@@ -915,7 +915,7 @@ def to_bool(val):
 class BaseCtrl:
     def __init__(self, text_id, name, type, value = None, default = None, min = None, max = None, step = None,
                 inactive = False, updater = False, reopener = False, menu_dd = False, menu = None, tooltip = None,
-                zeroer = False, kernel_id = None):
+                zeroer = False, wbtemperature = False, kernel_id = None):
         self.text_id = text_id
         self.kernel_id = kernel_id
         self.name = name
@@ -932,6 +932,7 @@ class BaseCtrl:
         self.menu = menu
         self.tooltip = tooltip
         self.zeroer = zeroer
+        self.wbtemperature = wbtemperature
 
 class BaseCtrlMenu:
     def __init__(self, text_id, name, value):
@@ -1119,6 +1120,7 @@ LOGITECH_BRIO_GUID = b'\x15\x02\xe4\x49\x34\xf4\xfe\x47\xb1\x58\x0e\x88\x50\x23\
 LOGITECH_BRIO_FOV_DEV_MATCH = [
     '046d:085e', # Brio
     '046d:0943', # Brio 500
+    '046d:0946', # Brio 501
     '046d:086b', # Brio 4K Stream Edition
 ]
 LOGITECH_BRIO_FOV_SEL = 0x05
@@ -1474,6 +1476,9 @@ class V4L2Ctrls:
                     v4l2ctrl.zeroer = True
                     v4l2ctrl.default = 0
 
+                if qctrl.id == V4L2_CID_WHITE_BALANCE_TEMPERATURE:
+                    v4l2ctrl.wbtemperature = True
+
                 if qctrl.type in [V4L2_CTRL_TYPE_MENU, V4L2_CTRL_TYPE_INTEGER_MENU]:
                     v4l2ctrl.menu = []
                     for i in range(qctrl.minimum, qctrl.maximum + 1):
